@@ -5,6 +5,7 @@ Management of the refinements' Tree from a schema.
 import logging
 from collections import OrderedDict
 
+from core_main_app.utils.requests_utils.access_control import SYSTEM_REQUEST
 from core_main_app.utils.xsd_flattener.xsd_flattener_database_url import (
     XSDFlattenerDatabaseOrURL,
 )
@@ -119,10 +120,9 @@ def _get_flatten_schema(template):
     Returns:
 
     """
-    flatten = XSDFlattenerDatabaseOrURL(template.content)
-    ref_xml_schema_content = flatten.get_flat()
-
-    return ref_xml_schema_content
+    return XSDFlattenerDatabaseOrURL(
+        template.content, request=SYSTEM_REQUEST
+    ).get_flat()
 
 
 def _get_target_namespace_prefix(ref_xml_schema_content, xml_doc_tree):
